(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-58f061a3"],{"5fd5":function(t,a,e){t.exports=e.p+"img/nest-desktop-logo.08d91bc0.png"},6860:function(t,a,e){t.exports=e.p+"img/eu-logo.89fc54c9.png"},"926a":function(t,a,e){t.exports=e.p+"img/nest-simulated.12f86949.png"},bb51:function(t,a,e){"use strict";e.r(a);var n=function(){var t=this,a=t.$createElement,n=t._self._c||a;return n("div",{staticClass:"home"},[n("v-main",{staticStyle:{height:"100vh","overflow-y":"auto"}},[n("v-container",{staticClass:"fill-height"},[n("v-row",[n("v-col",{staticClass:"text-center pa-10"},[n("v-img",{staticClass:"my-6",attrs:{src:e("5fd5"),contain:"",height:"200"}}),n("h1",{staticClass:"display-3 font-weight-light"},[t._v("NEST Desktop")]),n("p",{staticClass:"subheading font-weight-regular ma-3"},[t._v("\n            An educational GUI for neuroscience\n          ")])],1)],1),n("v-row",[n("v-col",{staticClass:"text-center"},[n("v-btn",{staticClass:"mx-3",attrs:{to:"project"},domProps:{textContent:t._s("Start a new project")}}),n("v-menu",{scopedSlots:t._u([{key:"activator",fn:function(a){var e=a.on,s=a.attrs;return[n("v-btn",t._g(t._b({staticClass:"mx-3",domProps:{textContent:t._s("Load a project")},on:{click:t.loadProjects}},"v-btn",s,!1),e))]}}])},[n("v-list",{attrs:{dense:""}},t._l(t.state.projects,(function(a,e){return n("v-list-item",{key:e,attrs:{to:"project/"+a.id}},[n("v-list-item-title",{domProps:{textContent:t._s(a.name)}})],1)})),1)],1)],1)],1),n("v-spacer"),n("v-row",[n("v-col",{attrs:{cols:"12",md:"7"}},[n("v-card",{attrs:{flat:""}},[n("v-card-text",{staticClass:"text-justify"},[n("p",[t._v("\n                NEST Desktop is a web-based GUI application for NEST\n                Simulator, an advanced simulation tool for computational\n                neuroscience.\n              ")]),n("p",[t._v("\n                The application enables the rapid construction,\n                parametrization, and instrumentation of neuronal network\n                models. The primary objective is to provide an accessible\n                classroom tool that allows users to rapidly explore\n                neuroscience concepts without the need to learn a simulator\n                control language at the same time.\n              ")])])],1)],1),n("v-col",{attrs:{cols:"12",md:"5"}},[n("v-card",{staticClass:"app-details",attrs:{flat:""}},[n("v-card-text",{staticClass:"py-0"},[n("About")],1)],1)],1)],1),n("v-row",[n("v-col",{attrs:{cols:"3"}},[n("a",{attrs:{href:"https://www.nest-simulator.org",target:"_blank"}},[n("v-img",{attrs:{contain:"","max-height":"42",src:e("926a")}})],1)]),n("v-col",{attrs:{cols:"3"}},[n("a",{attrs:{href:"https://www.humanbrainproject.eu",target:"_blank"}},[n("v-img",{attrs:{contain:"","max-height":"42",src:e("cbb9")}})],1)]),n("v-col",{attrs:{cols:"3"}},[n("a",{attrs:{href:"https://www.ebrains.eu",target:"_blank"}},[n("v-img",{attrs:{contain:"","max-height":"42",src:e("bd65")}})],1)]),n("v-col",{attrs:{cols:"3"}},[n("a",{attrs:{href:"https://europa.eu/european-union/index_en",target:"_blank"}},[n("v-img",{attrs:{contain:"","max-height":"42",src:e("6860")}})],1)])],1)],1)],1)],1)},s=[],o=e("2b0e"),c=e("a6f4"),i=e("5339"),r=e("84ba"),l=o["default"].extend({name:"Home",components:{About:r["a"]},setup:function(){var t=Object(c["e"])({projects:i["a"].app.projects}),a=function(){t.projects=i["a"].app.projects};return{loadProjects:a,state:t}}}),p=l,d=(e("cccb"),e("2877")),u=e("6544"),m=e.n(u),f=e("8336"),v=e("b0af"),g=e("99d9"),h=e("62ad"),b=e("a523"),w=e("adda"),x=e("8860"),C=e("da13"),_=e("5d23"),j=e("f6c4"),y=e("e449"),k=e("0fd9"),V=e("2fa4"),S=Object(d["a"])(p,n,s,!1,null,null,null);a["default"]=S.exports;m()(S,{VBtn:f["a"],VCard:v["a"],VCardText:g["c"],VCol:h["a"],VContainer:b["a"],VImg:w["a"],VList:x["a"],VListItem:C["a"],VListItemTitle:_["c"],VMain:j["a"],VMenu:y["a"],VRow:k["a"],VSpacer:V["a"]})},bd0c:function(t,a,e){},bd65:function(t,a,e){t.exports=e.p+"img/ebrains-logo.8ce61704.png"},cbb9:function(t,a,e){t.exports=e.p+"img/hbp-logo.c77da7bc.jpeg"},cccb:function(t,a,e){"use strict";e("d563")},d563:function(t,a,e){},f6c4:function(t,a,e){"use strict";e("bd0c");var n=e("d10f");a["a"]=n["a"].extend({name:"v-main",props:{tag:{type:String,default:"main"}},computed:{styles:function(){var t=this.$vuetify.application,a=t.bar,e=t.top,n=t.right,s=t.footer,o=t.insetFooter,c=t.bottom,i=t.left;return{paddingTop:"".concat(e+a,"px"),paddingRight:"".concat(n,"px"),paddingBottom:"".concat(s+o+c,"px"),paddingLeft:"".concat(i,"px")}}},render:function(t){var a={staticClass:"v-main",style:this.styles,ref:"main"};return t(this.tag,a,[t("div",{staticClass:"v-main__wrap"},this.$slots.default)])}})}}]);