.about .v-list{font-size:12px}.about .v-list-item{height:28px!important;min-height:28px!important}.about a{text-decoration:none;color:#000!important}.about .col-4,.about .col-8{padding:4px}.v-input__slot{-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.navigation .flex{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%}.navigation .nav-item{font-size:7px;text-align:center;width:100%}@media print{.no-print{display:none!important}.print{display:block!important}.v-main{padding:0!important}@page{size:landscape}}.iframe{background-color:#fff;display:none;position:absolute;z-index:1000}.v-toast__text h1{font-size:20px}.v-toast__text p{margin:4px 0}.fade-enter-active{-webkit-transition:opacity .5s;transition:opacity .5s}.fade-enter,.fade-leave-active{opacity:0}.network.icon path{fill:none;stroke-width:1.8;stroke:currentColor}