(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-7eff06f0"],{"26d3":function(t,e,a){"use strict";a.r(e);var n=function(){var t=this,e=t.$createElement,a=t._self._c||e;return a("div",{staticClass:"settings"},[a("v-card",{staticStyle:{height:"calc(100vh)","overflow-y":"auto"},attrs:{color:"white",flat:"",tile:""}},[a("v-main",[a("v-container",[a("v-card",{attrs:{flat:"",tile:""}},[a("v-card-title",{domProps:{textContent:t._s("App")}}),a("v-card-text",[a("v-checkbox",{attrs:{label:"Development mode"},on:{change:function(e){return t.updateAppConfig({devMode:e||!1})}},model:{value:t.state.devMode,callback:function(e){t.$set(t.state,"devMode",e)},expression:"state.devMode"}}),a("v-checkbox",{attrs:{label:"Pin navigation (Reload page required.)"},on:{change:function(e){return t.updateAppConfig({pinNav:e||!1})}},model:{value:t.state.pinNav,callback:function(e){t.$set(t.state,"pinNav",e)},expression:"state.pinNav"}}),a("v-checkbox",{attrs:{label:"Show help"},on:{change:function(e){return t.updateProjectConfig({showHelp:e||!1})}},model:{value:t.state.showHelp,callback:function(e){t.$set(t.state,"showHelp",e)},expression:"state.showHelp"}})],1)],1),a("v-card",{attrs:{flat:"",tile:""}},[a("v-card-title",{domProps:{textContent:t._s("Database")}}),a("v-card-text",[a("v-text-field",{attrs:{label:"Model database"},model:{value:t.state.app.config.databases.model.name,callback:function(e){t.$set(t.state.app.config.databases.model,"name",e)},expression:"state.app.config.databases.model.name"}}),a("v-text-field",{attrs:{label:"Project database"},model:{value:t.state.app.config.databases.project.name,callback:function(e){t.$set(t.state.app.config.databases.project,"name",e)},expression:"state.app.config.databases.project.name"}})],1)],1),a("v-card",{attrs:{flat:"",tile:""}},[a("v-card-title",{domProps:{textContent:t._s("Backend")}}),a("v-card-text",[a("v-text-field",{attrs:{label:"NEST Server"},model:{value:t.state.app.nestServer.url,callback:function(e){t.$set(t.state.app.nestServer,"url",e)},expression:"state.app.nestServer.url"}}),t.state.nestVersion?a("span",[t._v("\n              Response:\n              "),a("v-chip",{attrs:{color:"orange darken-3",dark:"",small:""}},[a("v-avatar",{attrs:{left:""}},[a("v-icon",{attrs:{small:""},domProps:{textContent:t._s("mdi-checkbox-marked-circle")}})],1),t._v("\n                NEST version: "+t._s(t.state.nestVersion)+"\n              ")],1)],1):t._e()],1),a("v-card-actions",[a("v-btn",{on:{click:t.checkNEST}},[t._v("Check")])],1)],1),a("v-card",{attrs:{flat:"",tile:""}},[a("v-card-title",{domProps:{textContent:t._s("Network")}}),a("v-card-text",[a("v-card",{attrs:{flat:"",tile:""}},[a("v-card-subtitle",{domProps:{textContent:t._s("Color cycle of nodes")}}),a("v-row",t._l(t.state.network.config.color.cycle,(function(t){return a("v-sheet",{key:t,staticClass:"flex",attrs:{color:t,height:40}})})),1)],1)],1)],1)],1)],1)],1)],1)},o=[],s=a("2b0e"),c=a("a6f4"),r=a("9885"),i=a("5339"),l=s["default"].extend({name:"Settings",setup:function(){var t=Object(c["e"])({app:i["a"].app,devMode:i["a"].app.config.devMode,nestVersion:"",network:new r["a"]("Network"),pinNav:i["a"].app.config.pinNav,showHelp:i["a"].app.project.config.showHelp}),e=function(){i["a"].app.nestServer.check().then((function(){t.nestVersion=i["a"].app.nestServer.state.simulatorVersion}))},a=function(t){i["a"].app.updateConfig(t)},n=function(t){i["a"].app.project.updateConfig(t)};return{checkNEST:e,state:t,updateAppConfig:a,updateProjectConfig:n}}}),p=l,d=a("2877"),v=a("6544"),f=a.n(v),u=a("8212"),b=a("8336"),h=a("b0af"),m=a("99d9"),g=a("ac7c"),x=a("cc20"),k=a("a523"),C=a("132d"),w=a("f6c4"),V=a("0fd9"),S=a("8dd9"),_=a("8654"),N=Object(d["a"])(p,n,o,!1,null,null,null);e["default"]=N.exports;f()(N,{VAvatar:u["a"],VBtn:b["a"],VCard:h["a"],VCardActions:m["a"],VCardSubtitle:m["b"],VCardText:m["c"],VCardTitle:m["d"],VCheckbox:g["a"],VChip:x["a"],VContainer:k["a"],VIcon:C["a"],VMain:w["a"],VRow:V["a"],VSheet:S["a"],VTextField:_["a"]})},bd0c:function(t,e,a){},f6c4:function(t,e,a){"use strict";a("bd0c");var n=a("d10f");e["a"]=n["a"].extend({name:"v-main",props:{tag:{type:String,default:"main"}},computed:{styles:function(){var t=this.$vuetify.application,e=t.bar,a=t.top,n=t.right,o=t.footer,s=t.insetFooter,c=t.bottom,r=t.left;return{paddingTop:"".concat(a+e,"px"),paddingRight:"".concat(n,"px"),paddingBottom:"".concat(o+s+c,"px"),paddingLeft:"".concat(r,"px")}}},render:function(t){var e={staticClass:"v-main",style:this.styles,ref:"main"};return t(this.tag,e,[t("div",{staticClass:"v-main__wrap"},this.$slots.default)])}})}}]);